#
# spec file for package tcl
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{!?_rpmmacrodir:1}
%define _rpmmacrodir %{_rpmconfigdir}/macros.d
%endif

Name:           tcl
URL:            http://www.tcl.tk
Version:        8.6.15
Release:        1.1
%define         rrc %{nil}
%define TCL_MINOR %(echo %version | cut -c1-3)
%define itclver 4.3.0
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Summary:        The Tcl Programming Language
License:        TCL
Group:          Development/Languages/Tcl
Provides:       itcl = %itclver
Provides:       tclsh
Provides:       tclsh%{TCL_MINOR}
Obsoletes:      itcl < %itclver
# Require the extension from the SQLite package instead of shipping
# the embedded copy, which might be outdated.
Requires:       sqlite3-tcl
# bug437293
%ifarch ppc64
Obsoletes:      tcl-64bit
%endif
#
PreReq:         /bin/rm
Source0:        http://prdownloads.sourceforge.net/tcl/%{name}%{version}%{rrc}-src.tar.gz
Source1:        tcl-rpmlintrc
Source2:        baselibs.conf
Source3:        macros.tcl
BuildRequires:  autoconf
BuildRequires:  pkg-config
BuildRequires:  zlib-devel
# Required for test suite:
BuildRequires:  timezone

%description
Tcl (Tool Command Language) is a very powerful but easy to learn
dynamic programming language, suitable for a very wide range of uses,
including web and desktop applications, networking, administration,
testing and many more. Open source and business-friendly, Tcl is a
mature yet evolving language that is truly cross platform, easily
deployed and highly extensible.

For more information on Tcl see http://www.tcl.tk and
http://wiki.tcl.tk .

%package devel
Summary:        Header Files and C API Documentation for Tcl
Group:          Development/Libraries/Tcl
Requires:       tcl = %version
# bug437293
%ifarch ppc64
Obsoletes:      tcl-devel-64bit
%endif
Obsoletes:      itcl-devel < %itclver
Provides:       itcl-devel = %itclver
#

%description devel
This package contains header files and documentation needed for writing
Tcl extensions in compiled languages like C, C++, etc., or for
embedding the Tcl interpreter in programs written in such languages.

This package is not needed for writing extensions or applications in
the Tcl language itself.

%prep
%setup -q -n %name%version
if ! test -d pkgs/itcl%itclver; then
   : New itcl version: pkgs/itcl* . Please update the %%itclver macro acordingly.
   exit 1
fi

# The SQLite extension is provided by the sqlite3 package,
# so don't build it here.
rm -r pkgs/sqlite3.*

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
%define scriptdir %_libdir/tcl
export TCL_PACKAGE_PATH="%scriptdir:%_datadir/tcl"
export TCL_LIBRARY="%scriptdir/tcl%TCL_MINOR"
cd unix
autoconf
%configure \
	--enable-man-symlinks \
	--enable-man-compression=gzip \
	--without-tzdata
make %{?_smp_mflags} \
	PACKAGE_DIR="%scriptdir"

%check
cd unix
# Some of the regressioin tests write to $HOME, so better redirect them
mkdir home
export HOME=$PWD/home
# Run the testsuite to gather some data for the profile-based
# optimisation and let rpmbuild fail on unexpected test failures.
cat > known-failures <<EOF
async-4.2
async-4.3
chan-17.4
chan-io-53.9
clock-33.5a
clock-33.8
clock-33.8a
event-7.5
event-11.4
event-12.4
exec-19.1
http-3.25
interp-34.9
interp-34.13
interp-36.7
io-53.9
msgcat-14.2
socket_inet6-2.13
timer-1.1
timer-2.1
timer-3.2
timer-6.4
timer-6.5
thread-7.24
thread-7.25
thread-7.28
thread-7.29
thread-7.30
thread-7.31
thread-20.9
thread-21.16
%ifarch riscv64
binary-40.3
%endif
%if 0%{?qemu_user_space_build}
socket-14.15
thread-16.2
%endif
EOF
%ifnarch s390 s390x
make test 2>&1 | tee testresults
grep FAILED testresults | grep -Fvwf known-failures && exit 1
%endif
exit 0

%install
make -C unix install install-private-headers \
	INSTALL_ROOT=%buildroot
rm -f %buildroot%scriptdir/tcl%TCL_MINOR/ldAix
ln -sf tclsh%TCL_MINOR %buildroot%_prefix/bin/tclsh
ln -sf tclsh.1.gz %buildroot%_mandir/man1/tclsh%TCL_MINOR.1.gz
mkdir -p %buildroot%_datadir/tcl
install -D %{S:3} -m 644 %buildroot%_rpmmacrodir/macros.tcl

# The information in TCL_LIBS is not needed for shared libraries
# and we don't support static linking.
sed -i "/^TCL_LIBS=/s/'.*'$//" %buildroot%_libdir/tclConfig.sh
sed -i "/^Libs.private: /s/ .*$//" %buildroot%_libdir/pkgconfig/tcl.pc

%if "%_lib" == "lib64"
%post
test -L /usr/lib/tcl%TCL_MINOR && /bin/rm -f /usr/lib/tcl%TCL_MINOR
exit 0
%endif

%files
%defattr(-,root,root,755)
%doc README.md changes license.terms ChangeLog*
%docdir %_mandir/mann
%doc %_mandir/man1/*
%doc %_mandir/mann/*
%_prefix/bin/*
%_libdir/lib*.so
%_datadir/tcl
%scriptdir
%exclude %scriptdir/*/*.a
%exclude %scriptdir/*/*Config.sh
%exclude %scriptdir/*/tclAppInit.c
%_rpmmacrodir/macros.tcl

%files devel
%defattr(-,root,root)
%doc %_mandir/man3/*
%_includedir/*
%scriptdir/*/tclAppInit.c
%attr(0644,root,root) %_libdir/*.a
%attr(0644,root,root) %scriptdir/*/*.a
%scriptdir/*/*Config.sh
%_libdir/*Config.sh
%_libdir/pkgconfig/*

%changelog
* Tue Sep 24 2024 Reinhard Max <max@suse.com>
- TCL_PACKAGE_PATH now needs to be a unix-style path separated by
  colons rather than a Tcl list.
* Fri Sep 13 2024 Reinhard Max <max@suse.com>
- Version 8.6.15:
  * [d63061] remove private unicode 0xE000-0xF8FF from unicode
    control group
  * [1b8a89] TCL_PACKAGE_PATH in tclConfig.sh change from TCL list
    to ":" separated items
  * ** POTENTIAL INCOMPATIBILITY ***
  * [1acd17] fix compiled mapped ensembles
  * [f23022] fix encoding koi8-u codepoint 0xB4
  * [6811a0] speedup op unicode transformation related operations
  * Add encodings: koi8-ru, koi8-t
  * [7cb740] Fix Tcl_ParseArgsObjv with TCL_ARGV_GENFUNC option
  * Hash speedup for pointer compare. Option
    TCL_HASH_KEY_DIRECT_COMPARE for hash tables
  * [TIP 692] Deprecate Tcl_GetAlias()
  * [a5f4a7] Correct tcl::tm::path autoload
  * [3c26de] Remove empty all items from tclConfig.sh path
    variables.
  * [87271f] Fix crash in oo+coroutine
  * [7842f3] fix crash in oo destructors in same namespace
  * [79474c] Fix crash in reflected channels
  * [c6897e] Fix crash due to unchecked file descriptor size
  * [3fc328] Fix report of non ASCII computer names on Windows
  * [e3f4a8] Fix error message caused by interp limit
  * [1d26e5] Source files with BOM also in safe interpreters
  * [5fca83] Fix encoding system result for system locale
    ISO-8859-1
  * [0de6c1] Fix crash in [child invokehidden info frame]
  * [74b611] Fix removal of oo variable by [info exists]
  * [91b3a5] Make [self] work inside [$obj eval]
  * [154f09] Tcl_NewObjectInstance() errors on namespace re-use
  * ** POTENTIAL INCOMPATIBILITY -- breaks Itcl 4.2 ***
  * [2da1cb] Fix [$obj varname] for linked varnames
  * Unicode version 16
  * [7179c6] Fix byte compiled [incr] with wide int increment
* Fri Mar  1 2024 Reinhard Max <max@suse.com>
- Version 8.6.14:
  * Backport TIP #402: path name starting with '//' not replaced by
    '/' also on Cygwin and QNX
  * (bug) [8f7fde] string compare failing on big endian
  * (bug) [3e8074] y2k38 problem in [interp limit time -seconds]
  * (bug) [e3dcab] crash with tcl_precision equal 15..18
  * (bug) [d19fe0] output replacement character on incomplete
    sequences in unicode encoding
  * (bug) [534172] sporadic crash in memchan thread cleanup.
  * (bug) [f9eafc] throw error in zip command when file
    comment/filename to long or not iso-latin-1
  * (bug)[183a1a] Prevent BO by Tcl_UtfToExternal
  * (bug) [ea69b0], crash when using a channel transformation on
    TCP client socket
  * (bug)[026575] Prevent invalid read in Tcl_UtfToUniChar
  * (rfe) Allow empty mode in [chan create] to allow refchan
    version of [socket -server]
  * (bug) [ab123c] argument position overflow in [scan %%num$mode]
  * (bug) [784bef] tailcall crash
  * (bug) [af3ebc] clock scan and clock add bugs in error cases /
    with abbreviated options
  * (bug) [66ffaf] incomplete double byte encoding sequences
    ignored like in [encoding convertfrom gb12345 x]
  * (rfe) [c54e4a] fork multithreading performance by using
    vfork/spawn when supported
  * Update libtommath to version 1.2.1
  * (bug) [60cacf] Fix tclvfs tkt Segmentation Fault at
    interpreter exit when tclvfs loaded.
  * (bug) [b5ac3e] Tcl_GetUniChar reads beyond string length for
    ASCII strings
  * Unicode 15.1
  * (bug) [00655c] ClockGetdatefieldsObjCmd(): avoid signed integer
    overflow and platform-dependent behavior
  * TIP #662: Tcl_VarEval is not depreciated any more
  * (bug) [7b3167] tclOO.c: initialize fakeObject.refCount
  * (bug) [7371b6] AddressSanitizer use-after-return detection
    breaks NRE tests, coroutines
  * (bug)[32b889] prevent spurious errors from [clock format]
  * (rfe) [0ac9d0] Don't call getsockname(2) in
    Tcl_MakeFileChannel(3) unless absolutely necessary. Permits
    better constraining of Tcl/tclsh via OpenBSD's pledge(2) or
    similar mechanisms. Minor rewrite.
  * (feature) Adapt tcltest to support Tcl 9.
  * (bug) [fd27ad] doc change of Tcl_PkgRequire & friends: version
    string specification refers to "package require".
  * (bug) [16e25e] error for
    [tcl_startOfPreviousWord string end-1]
  * [db4f28] segfault when Tcl_ReadChars is called with unicode
    object
  * fix/document Tcl_ObjPrintf with "ll" modifier
  * [8e666d] endless loop when redefining proc ::history
  * [86b3c1] endless loop when ::unknown is moved into a namespace
- Obsoleted patches:
  * tcl-interp-limit-time.patch
  * tcl-refchan-mode-needed.patch
  * tcl-string-compare.patch
* Thu Mar 30 2023 Reinhard Max <max@suse.com>
- Update tcl-refchan-mode-needed.patch to the upstream version.
* Mon Feb  6 2023 Reinhard Max <max@suse.com>
- bsc#1203982, tcl-interp-limit-time.patch: Fix a y2k38 problem
  in [interp limit -time] .
* Tue Jan 17 2023 Reinhard Max <max@suse.com>
- bsc#1206623: adopt upstream patch for an improved fix that does
  not remove the optimisation.
* Fri Dec 23 2022 Reinhard Max <max@suse.com>
- bsc#1206623, tcl-string-compare.patch: Fix a bug in string
  comparison on big endian that made test string-2.20.1 fail.
* Wed Nov 23 2022 Reinhard Max <max@suse.com>
- New version 8.6.13:
  * (bug)[26f132] Crash when sizeof(int) < sizeof(void *)
  * (TIP 623)[e9a271] Tcl_GetRange index args < 0
  * (bug)[e5ed1b] numeric IPv6 in URLs
  * (bug)[8eb64b] http package tolerant again invalid reply header
  * (bug)[6898f9] http package failed detection of shiftjis charset
  * (bug)[55bf73] Avoid connection reuse after response code 101.
  * (bug)[713653] FP rounding exposed by x86 musl
  * (bug)[b3977d] Process CR-LF split across packets
  * (bug)[4eb3a1] crash due to undetected bytecode invalidity
  * (bug)[55a02f] Fallback init env(HOME) from USERPROFILE
  * (bug)[1073da] crash writing invalid utf-8
  * (new) Update to Unicode-15
  * Many code fixes to avoid overflow or undefined behavior.
- Add tcl-refchan-mode-needed.patch to allow refchans to be opened
  for neither reading nor writing, but still handle events.
* Wed Sep 21 2022 Dirk Müller <dmueller@suse.com>
- skip more tests with qemu_user builds (e.g. riscv64)
* Tue Mar 29 2022 Reinhard Max <max@suse.com>
- Remove the SQLite extension and package it as a subpackage of
  sqlite3 to have only a single copy and keep it more up to date
  (bsc#1195773).
- Clean up the lib dependencies in tclConfig.sh and tcl.pc.
* Tue Nov  9 2021 Reinhard Max <max@suse.com>
- New version 8.6.12:
  * (bug)[d43f96] [string trim*] broken for Emoji
  * (bug)[22324b] [string reverse] broken for Emoji
  * (bug)[1dab71,7c64aa] BRE broken by uninitialized value use
  * (bug)[8419c5] Unix tty channels tolerate EINTR
  * ** POTENTIAL INCOMPATIBILITY ***
  * (bug)[4c591f] [string compare] EIAS violation
  * (bug)[266494] [concat foo [list #]] EIAS violation
  * (bug)[24b918] Save IO buffers from modern optimizers
  * (new) support for POSIX error EILSEQ
  * (bug)[688fcc] segfault during traced delete of alias
  * (bug)[ccc448] segfault in ensemble rewrite machinery
  * (new) Update to Unicode-14
  * (bug)[a8579d] failed proc argument spec processing
  * Obsoletes tcl-aa4a13c15516da45.patch
- Bump %%itclver and ensure it stays in sync.
* Wed May  5 2021 Reinhard Max <max@suse.com>
- bsc#1185662: Move tcl.macros /usr/lib/rpm/macros.d .
- https://core.tcl-lang.org/thread/tktview?name=98ae20f0f5:
  Add tcl-aa4a13c15516da45.patch to disable lto for the stubs
  libraries.
* Thu Jan 14 2021 Reinhard Max <max@suse.com>
- tclConfig.sh: Fix path names and avoid braces in TCL_PACKAGE_PATH
- Set TCL_LIBRARY at configure time for better consistency.
* Mon Jan  4 2021 Reinhard Max <max@suse.com>
- New version: 8.6.11:
  * Add tcltest::(Setup|Eval|Cleanup|)Test
  * Update to Unicode-13
  * Add 3 libtommath functions to stub table
  * Many more bug fixes
- Potentially incompatible changes:
  * (bug)[ffeb20] [binary decode base64] ignore invalid chars
  * (bug)[b8e82d] some -maxlen values break uuencode round trip
  * (bug)[085913] Tcl_DStringAppendElement # quoting precision
  * (bug)[81242a] revised documentation for Tcl_UtfAtIndex()
  * (bug)[ed2980] Tcl_UtfToUniChar reads > TCL_UTF_MAX bytes
  * (bug)[a1bd37] [clock scan] new ISO format (clock-34.(19-24))
  * (bug)[501974] [clock scan] +time zone (clock-34.(53-68))
  * (new) force -eofchar \032 when evaluating library scripts
  * (new)[48898a] improve error message consistency
  * (new) revised case of module names
* Fri Nov 20 2020 Reinhard Max <max@suse.com>
- Add a manpage symlink for tclsh8.6.
* Fri Oct  9 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.16: error: bare words are no longer
  supported, please use "...":  lib64 == lib64.
* Tue Dec  3 2019 Reinhard Max <max@suse.com>
- New version: 8.6.10:
  * (bug)[7a9dc5] [file normalize ~/~foo] segfault
  * (bug)[3cf3a9] variable 'timezone' deprecated in vc2017
  * (bug)[cc1e91] [list [list {*}[set a " "]]] regression
    obsoletes tcl-expand-regression.patch.
  * (bug)[e3f481] tests var-1.2[01]
  * (new) Update to Unicode 12.0
  * (new)[TIP 527] New command [timerate]
  * (bug)[39fed4] [package require] memory validity
  * (new) New command tcl::unsupported::corotype
  * (bug) memlink when namespace deletion kills linked var
  * (new) README file converted to README.md in Markdown
  * (bug)[8b9854] [info level 0] regression with ensembles
  * (bug)[6bdadf] crash multi-arg write-traced [lappend]
  * (bug)[f8a33c] crash Tcl_Exit before init
  * (bug)[fa6bf3] Bytecode fails epoch recovery at numLevel=0
  * (bug)[fec0c1] C stack overflow compiling bytecode
  * tzdata updated to Olson's tzdata2019c
  * (bug)[16768d] Fix [info hostname] on NetBSD
  * (new) libtommath updated to release 1.2.0
  * (bug)[bcd100] bad fs cache when system encoding changes
  * (bug)[135804] segfault in [next] after destroy
  * (bug)[13657a] application/json us text, not binary
* Tue Jul  9 2019 Andreas Schwab <schwab@suse.de>
- binary-40.3 is expected to fail on riscv64 which does not support NaN
  propagation
* Thu Jun 20 2019 Martin Liška <mliska@suse.cz>
- Use FAT LTO objects in order to provide proper static
  library (boo#1138797).
* Thu Jan 17 2019 Reinhard Max <max@suse.com>
- Fix a regression in the handling of denormalized empty lists
  (tcl-expand-regression.patch, tcl#cc1e91552c).
* Wed Dec 12 2018 Reinhard Max <max@suse.com>
- New version: 8.6.9:
  * NR-enable [package require]
  * (bug)[9fd5c6] crash in object deletion, test oo-11.5
  * (bug)[3c32a3] crash deleting object with class mixed in
  * (platform) stop using -lieee, removed from glibc-2.27
    (bsc#1179615, bsc#1181840).
  * (bug)[8e6a9a] bad binary [string match], test string-11.55
  * (bug)[1873ea] repair multi-thread std channel init
  * (bug)[db36fa] broken bytecode for index values
  * (bug) broken compiled [string replace], test string-14.19
  * (bug) [string trim*] engine crashed on invalid UTF
  * (bug) missing trace in compiled [array set], test var-20.11
  * (bug)[46a241] crash in unset array with search, var-13.[23]
  * (bug)[27b682] race made [file delete] raise "no such file"
  * (bug)[925643] 32/64 cleanup of filesystem DIR operations
  * (bug) leaks in TclSetEnv and env cache
  * (bug)[3592747] [yieldto] dying namespace, tailcall-14.1
  * (bug)[270f78] race in [file mkdir]
  * (bug)[3f7af0] [file delete] raised "permission denied"
  * (bug)[d051b7] overflow crash in [format]
  * revised quoting of [exec] args in generated command line
  * HTTP Keep-Alive with pipelined requests
  * (new)[TIP 505] [lreplace] accepts all out of range indices
  * (bug) Prevent crash from NULL keyName in the registry package
  * Update tcltest package for Travis support
  * (bug)[35a8f1] overlong string length of some lists
  * (bug)[00d04c] Repair [binary encode base64]
* Thu Mar 15 2018 ro@suse.de
- handle s390 like s390x (bnc#1085480)
* Fri Dec 29 2017 max@suse.com
- Version 8.6.8:
  * [array names -regexp] supports backrefs
  * Fix gcc build failures due to #pragma placement
  * (bug)[b50fb2] exec redir append stdout and stderr to file
  * (bug)[2a9465] http state 100 continue handling broken
  * (bug)[0e4d88] replace command, delete trace kills namespace
  * (bug)[1a5655] [info * methods] includes mixins
  * (bug)[fc1409] segfault in method cloning, oo-15.15
  * (bug)[3298012] Stop crash when hash tables overflow 32 bits
  * (bug)[5d6de6] Close failing case of [package prefer stable]
  * (bug)[4f6a1e] Crash when ensemble map and list are same
  * (bug)[ce3a21] file normalize failure when tail is empty
  * (new)[TIP 477] nmake build system reform
  * (bug)[586e71] EvalObjv exception handling at level #0
* Thu Dec 14 2017 mls@suse.de
- adapt check section for rpm-4.14.0
* Thu Dec 14 2017 normand@linux.vnet.ibm.com
- Add more tests in Whitelist as bypass boo#1072657
  identified following tests failed on PowerPC
  interp-34.9 interp-34.13 http-3.25 timer-2.1 thread-20.9
* Thu Oct 19 2017 max@suse.com
- Sync SLE12 with Factory to fix a bug in Itcl that was affecting
  iwidgets (bsc#903017).
* Mon Sep 25 2017 max@suse.com
- Whitelist known-failing tests. Further investigation needed.
* Fri Aug 11 2017 max@suse.com
- New version: 8.6.7:
  * (bug)[c09edf] Bad caching with  custom resolver
  * (bug)[4dbdd9] Memleak in test var-8.3
  * (bug)[2bf561] Allow empty command as alias target
  * ** POTENTIAL INCOMPATIBILITY ***
  * (bug)[4d5ae7] Crash in async connects host no address
  * (bug)[838e99] treat application/xml as text => http 2.8.10
  * (bug)[3cc1d9] Thread finalization crash in zippy
  * (bug)[be003d] Fix [scan 0x1 %%b], [scan 0x1 %%o]
  * (bug)[eb6b68] Fix stringComp-14.5
  * (bug)[b26e38] Fix zlib-7.8
  * (bug)[1ae129] Fix memleak in [history] destruction
  * (feature) Provisional Tcl 9 support in msgcat and tcltest
    => msgcat 1.6.1 => tcltest 2.4.1
  * (bug)[824752] Crash in Tcl_ListObjReplace()
  * (bug)[79614f] invalidate VFS mounts on sytem encoding change
  * (bug) TclOO fix stops crash mixing Itcl and snit
  * (update) Reconcile libtommath updates; purge unused files
  * ** POTENTIAL INCOMPATIBILITY ***
  * (bug)[b87ad7] Repair drifts in timer clock
  * (bug)[39f630] Revise Tcl_LinkVar to tolerate some prefixes
  * ** POTENTIAL INCOMPATIBILITY ***
  * (bug)[d0f7ba] Improper NAN optimization. expr-22.1[01]
  * (bug)[25842c] zlib stream finalization
  * (enhancement) [clock] and [encoding] are now ensembles
  * (enhancement) several [clock] subcommands bytecoded
  * (bug)[900cb0] Fix OO unexport introspection
  * (bug)[42202b] Nesting imbalance in coro injection
  * (bug)[bc4322] http package support for safe interps
  * (bug)[f34cf8] [file join a //b] => /b
  * (bug)[8bd13f] Windows threads and pipe
  * (bug)[f9fe90] [file join //a b] EIAS violation
  * (bug)[601522] [binary] field spec overflow -> segfault
  * (bug)[6ca52a] http memleak handling keep-alive=> http 2.8.11
  * (bug)[a3fb33] crash in [lsort] on long lists
  * (bug)[67aa9a] Tcl_UtfToUniChar() revised handling invalid UTF-8
  * ** POTENTIAL INCOMPATIBILITY ***
  * (bug)[2738427] Tcl_NumUtfChars() corner case utf-4.9
  * (update) Update Unicode data to 10.0
  * ** POTENTIAL INCOMPATIBILITY ***
  * (TIP 473) Let [oo::copy] specify target namespace
  * (bug)[46f801] Repair autoloader fragility
  * (bug)[adb198] Plug memleak in TclJoinPath
  * (bug)[fb2208] Repeatable tclIndex generation
- Included Itcl is now version 4.0.5.
* Sat Jul 22 2017 schwab@linux-m68k.org
- Add zlib-devel to BuildRequires, don't use included zlib sources
* Mon Feb 27 2017 schwab@suse.de
- Reenable testsuite on %%arm
* Wed Dec 21 2016 bg@suse.com
- Disable check for s390x for now
* Tue Jul 26 2016 max@suse.com
- New version 8.6.6:
  * (bug)[803042] mem leak due to reference cycle.
  * (bug)[bbc304] reflected watch race condition.
  * (bug)[fadc99] compile-5.3.
  * (enhancement)[1a25fd] compile [variable ${ns}::v]
  * (bug)[1af8de] crash in compiled [string replace]
  * (bug)[d30718] segv in notifier finalize
  * (enhancement)[7d0db7] parallel make
  * [f12535] enable test bindings customization
  * (bug)[47ac84] compiled [lreplace] fixes
  * ** POTENTIAL INCOMPATIBILITY ***
  * (bug)[866368] RE \w includes 'Punctuation Connector'
  * [07d13d] Restore TclBlend support lost in 8.6.1
  * (bug)[3154ea] Mem corruption in assembler exceptions
  * (bug) registry package support any Unicode env
    => registry 1.3.2
  * (bug)[f7d4e] [namespace delete] performance
  * (TIP 447) execution time verbosity option
    => tcltest 2.4.0
  * (bug)[16828b] crash due to [vwait] trace undo fail
  * (enhancement)[4b61af] good [info frame] from more cases.
  * (bug)[c383eb] crash in [glob -path a]
  * (update) Update Unicode data to 9.0 (nijtmans)
  * ** POTENTIAL INCOMPATIBILITY ***
  * (bug)[16896d] Tcl_DString tolerate append to self.
  * (bug)[d55322] crash in [dict update].
  * (bug)[dd260a] crash in [chan configure -dictionary].
  * (bug)[f961d7] usage message with parameters with spaces.
  * ** POTENTIAL INCOMPATIBILITY ***
  * (enhancement)[09fabc] Sort order of -relateddir.
  * (bug)[1493a4] [namespace upvar] use of resolvers.
  * ** POTENTIAL INCOMPATIBILITY ***
  * (bug)[da340d] integer division in clock math.
- Fix %%check ("make test" was run in the wrong directory).
* Tue Mar  1 2016 fweiss@suse.com
- New version 8.6.5:
  * (bug)[d87cb1] Proper tailcall from compiled ensembles
  * (bug)[879a07] Incomplete chars @ buffer ends
  * (bug)[894da1] Hang flushing blocking channels
  * (enhance)[b9d043] Default use of gzip transfer encoding
    => http 2.8.9
  * ** POTENTIAL INCOMPATIBILITY ***
  * (bug)[9dd1bd] destructor [self] after failed constructor
  * (bug)[0f42ff] [tailcall] combined with [next]
  * (bug)[c11a51] http: race condition in -accept option
  * (enhance) More pure lists from compiled [list]
  * (enhancement) Relax memdebug constraint on extensions
  * (bug)[268b23] crash in traced [expr]
  * (bug)[478c44] Memleak in zlib compresion errors
  * (bug)[e770d9] Higher baud on serial channels
  * (update) Update Unicode data to 8.0
  * ** POTENTIAL INCOMPATIBILITY ***
  * (bug)[a4cb3f] compiled [lreplace] handling of end
  * (enhance) Use Unicode SendMessageTimeout()
    => registry 1.3.1
  * (TIP 412) msgcat dynamic locale change and package private
    locale    => msgcat 1.6.0
  * (bug)[a0ece9] crash in traced [expr]
  * (TIP 436) [info object isa] favors 'false' over error
    => TclOO 1.0.4
  * (bug)[b1534b][9bad63] writes beyond buffer bounds
  * (bug)[a3309d] Memleak in compiled [unset a($i)]
  * (bug)[57945b] lock in forking/multi-threading
  * (bug)[3e7eca] Allocation overflow in expr parsing
  * (bug) Correct problems found in Coverity audit
  * (bug)[00189c] MSVC 14: semi-static UCRT support
  * (bug)[0df7a1] Tolerate getcwd() failures
  * (bug)[1115587][a3c350][d7ea9f][0e0e15][187d7f] Many fixes and
    improvements to regexp engine from Postgres
  * (enhance) hash lookup microoptimization
  * (bug)[e0a7b3] Input buffer draining & file events
  * (bug)[219866] Cygwin support error (yorick,nijtmans)
    => platform 1.0.14
  * (bug)[1080042][8f2450] More regexp from Postgres
  * (bug)[4a0c16] [clock] react to msgcat locale change
  * (bug)[261a8a] Overflow segfault in I/O translation
  * (bug)[40f628] ListObjReplace callers fail to detect max
  * (enhance)[32c574] Improve list growth performance
  * (bug)[c9eb6b] tolerate unset ::env(TZ)
  * (TIP 440) tcl_platform(engine) -- Tcl implementation
  * (bug)[25842c] stream [zlib deflate] fails with 0 input
  * (bug)[3d96b7][593baa][cf74de] crashes in OO teardown
  * (bug)[9b4702] [info exists env(missing)] kills trace
* Wed Jul 29 2015 max@suse.com
- New version 8.6.4:
  * restore tbcload/tclcompiler support
  * (bug)[0c043a] Fix compiled [set var($) val]
  * (bug)[d2ffcc] Limit $... and bareword parsing to ASCII
  * ** POTENTIAL INCOMPATIBILITY ***
  * (TIP 427) [fconfigure $h -connecting, -peername, -sockname]
  * (bug)[af08c8] Crash in full finalize encoding teardown
  * (bug)[7c187a] [chan copy] crash (io-53.17)
  * (bug)[df0848] Trouble with INFINITY macro
  * (bug) Stop crashes when extension var resolvers misbehave
  * (bug)[088727] [read] past EOF (io-73.4)
  * (bug)[32b615] Fix compiled [lreplace] (lreplace-4.[345])
- Obsoletes itcl-unbreak-iwidgets.patch
* Wed Nov 12 2014 max@suse.com
- New version 8.6.3:
  * (bug)[b9e1a3] Correct Method Search Order
  * (bug)[ccc2c2] Regression [lreplace {} 1 1]
  * <oo-1.18.2> Crash regression in [oo::class destroy]
  * (bug)[84af11] Regress [regsub -all {\(.*} a(b) {}]
  * (bug)[cee90e] [try {} on ok {} - on return {} {}] panic
  * (feature) [tcl::unsupported::getbytecode] disassember
  * (enhancement) [string cat] bytecode optimization
  * (bug)[82521b] segfault in mangled bytecode
  * (bug)[bc5b79] Hang in some [read]s of limited size
  * (bug)[bc1a96] segfault in [array set] of traced array
  * (bug)[59a2e7] MSVC14 compile support
  * (bug)[ed29c4] [fcopy] treats [blocked] as error
  * (bug)[bf7135] regression in Tcl_Write() interface
  * (bug)[10dc6d] fix [gets] on non-blocking channels
  * (bug)[214cc0] Restore [lappend v] return value
  * (bug)[5adc35] Stop forcing EOF to be permanent
- Add itcl-unbreak-iwidgets.patch to revert a recent change in
  itcl that broke iwidgets.
* Sat Sep  6 2014 coolo@suse.de
- avoid %%nil to pass download_files service
* Mon Sep  1 2014 fcrozat@suse.com
- Update license tag to SPDX 1.2.
- Remove obsolete patches tcl-unload.patch and tcl.patch.
* Thu Aug 28 2014 vwallfahrer@suse.com
- Update to 8.6.2:
  * TIP 429: New command [string cat].
  * [lsearch -integer], [lsort -integer] operate on wide ints.
  * ** POTENTIAL INCOMPATIBILITY ***
  * [dict replace], [dict remove] return canonical dicts.
  * ** POTENTIAL INCOMPATIBILITY ***
  * Improved ::env synchronization with environment.
  * transchans converted blocked writes to errors.
  * [info class subclasses ::oo::object] includes ::oo::class .
  * Fix: [chan configure -error] breaks [socket -async] connection.
  * Better handle NUL in filenames.
  * Fix: failures in nested ensemble bytecode compiler.
  * Fixed crashes in...
  - [apply {{} {while 1 {a {*}
    [return -level 0 -code continue]}}}]
  - [apply {{} {namespace upvar a b [x]}}]
  - [coroutine X coroutine Y info frame]
  - multi-interp font teardown
  - oo chain deletion
  * Plugged memory leaks in...
  - execution traced coroutine deletion
  - [close [zlib push ... -dictionary ...]]
  - AtForkChild()
  - managing oo instance lists
  * Performance addressed in...
  - [lappend l $multiple $arg] compile: quadratic -> linear
  - binary [chan copy]: move bytes instead of copy
  - Improved bytecode: [catch], [foreach], [lmap],
    num. conversion
  * Bytecode compiled: [concat], [linsert], [namespace origin],
    [next], [nextto], [string is], [string replace],
    [string tolower], [string totitle], [string toupper],
    [string trim], [string trimleft],
    [string trimright] [yieldto]
  * New package releases:
    http 2.8.8:     Accept upper case schemes in URLs
    tcltest 2.3.7:   cleanup runs before output comparisons
    platform 1.0.13: Update macosx-* variant compatibilities
    TclOO 1.0.2
    itcl 4.0.1
    thread 2.7.1
    sqlite3 3.8.6
    tdbc* 1.0.1
- removed tcl-unload.patch and tcl.patch
* Fri Sep 20 2013 max@suse.com
- Final 8.6.1 release. Changes since rc0 include:
  * Fix segfaults in [dict] compilers.
  * Fix mem leak in [lreplace].
* Tue Sep 10 2013 kpetsch@suse.com
- New patchlevel release 8.6.1rc0:
- Many optimaizations, improvements and tightened stack management
  in bytecode
- Many enhancements and Bugfixes:
  * Improve ensemble bytecode
  * Selected script code improvements => tcltest 2.3.6
  * Broaden glibc version detection => platform 1.0.12
  * [array set] compile improvement
  * [auto_mkindex] support Tcl00
  * Tcl_Zlib*() routines tolerate NULL interps
  * Improved [list {*}...] compile
  * Restored lost performance appending to long strings
  * Errors from execution traces become errors of the command
* Thu Jun 20 2013 max@suse.com
- New version: 8.6.0.
- Itcl is now part of the Tcl main package.
- Disable profile feedback based optimization for now.
- Highlihhts of the new version:
  * Object Oriented Programming: The commands of the TclOO package
    are now part of Tcl itself. This gives Tcl a built-in object
    system that is fully dynamic, class-based, and includes
    advanced features such as meta-classes, filters, and mixins.
  * New version 4 of the popular package Itcl (aka incr Tcl) is
    also included, now built on a TclOO foundation, granting
    support for some traditional OO Tcl programming out of the box
    as well.
  * Stackless Evaluation: The evaluation of many levels of nested
    proc calls are no longer implemented as a stack of nested C
    routine calls. This revision in the internal implementation of
    Tcl evaluation makes deep recursion in Tcl scripts safe to
    do. But there's more...
  * This new implementation enables a collection of new commands,
    coroutine, tailcall, yield, and yieldto that provide profound
    new capabilities and models of concurrency to Tcl scripts.
  * Enhanced Exceptions: New commands try and throw and a wealth
    of new -errorcode values enable far more precise trapping and
    handling of exceptions using a familiar construct.
  * Batteries Included: Tcl delivers in the pkgs subdirectory a
    bundled collection of third-party packages built and installed
    along with Tcl.
  * Thread-enabled Operations: A thread-enabled default build, a
    bundled Thread package, and new command interp cancel make Tcl
    8.6 ready for your multi-threaded programming tasks.
  * SQL Database Powered: The bundled Tcl DataBase Connectivity
    (tdbc) interface package makes it possible to write your SQL
    database-powered scripts decoupled from any particular
    database engine. The bundled sqlite3 and tdbc::sqlite3
    packages supply a powerful and popular SQL database engine
    ready to use.
  * IPv6 Networking: Both client and server sockets support IPv6
    where platform support exists.
  * Built-in Zlib Compression: New command zlib provides utilities
    to handle compression of data and streams.
  * List Processing: New commands lmap and dict map enable the
    elegant expression of transformations over Tcl containers.
  * Stacked Channels by Script: New commands chan push and chan
    pop expose the power of stacked channels without the need to
    write C code.
  * Additional New Features: Temporary file creation, enhancements
    to list sorting and setting, dict filtering, half-close of
    bidirectional channels, encoding and decoding of binary
    sequences, finer control over load, and many many more.
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Sun Nov 25 2012 aj@suse.de
- The testsuite needs timezone data, require it at build time.
* Thu Aug  9 2012 max@suse.com
- New patchlevel: 8.5.12:
  * Fix the values returned by [switch -regexp -indexvar]
  * Improve RFC compliance of the http package
  * Several other bugfixes
* Sun Jul 29 2012 jengelh@inai.de
- Disable profiling on SPARC due to compiler bug [gcc #54121]
- Remove redundant tags/sections from specfile
- Parallel build with %%_smp_mflags
* Wed Jan  4 2012 cfarrell@suse.com
- license update: SUSE-TCL
  Use this proprietary extension to SPDX until upstream SPDX accepts TCL
  into their license list
* Wed Dec 21 2011 coolo@suse.com
- add autoconf as buildrequire to avoid implicit dependency
* Tue Nov  8 2011 max@suse.com
- New patchlevel release 8.5.11:
  * [3349507] correct double(1[string repeat 0 23])
  * [3371644] Tcl_ConvertElement() segfault
  * [3372130] hypot(.) segfault
  * [3389764] memleaks due to reference cycles in dup'd paths
  * [3390272] leak of [info script] value
  * [3393150] bignum leaks in Tcl_Get*() routines
  * [3393714] [string toupper] overflow
  * [3398794] panic in interp limit setting (gavlian,fellows)
  * [3401704] revised expr parser to permit function names like
    "nano()" instead of parsing as "nan o()" with missing op
  * ** POTENTIAL INCOMPATIBILITY ***
  * [3405652] DTrace workaround
  * [3391977] -headers overrides -type (=> http 2.7.7)
  * [3400658] wrong num args msg with TclOO
  * [2935503] [file stat] returns bad mode
* Tue Oct  4 2011 uli@suse.com
- cross-build fix: use %%__cc macro
* Thu Jun 30 2011 max@novell.com
- New patchlevel release 8.5.10:
  * Update Unicode data to 6.0
  * Fix handling of empty path lists in Safe Tcl.
  * (bug fix)[3098302] crash in compiled [catch]
  * (TIP 378)[3081184] improved TIP 280 performance
  * (enhancement) Restore TclFormatInt for performance
  * (enhancement) Tcl_PrintDouble performance improvements
  * (bug fix)[3142026] GrowEvaluationStack OBOE
  * (bug fix)[3072640] protect writes to ::error* variables
  * (bug fix)[3200987,3192636] parser buffer overruns
  * (bug fix)[3202905] failed intrep release of interp result
  * (bug fix)[3202171] repair [namespace inscope] optimizer
  * (bug fix) Fixes from libtommath 0.42.0 release
  * (bug fix)[3216070] [load] extension from embed Tcl apps
  * (bug fix)[3285472] intrep corruption in [string reverse]
  * (bug fix)[2662380] crash when variable append trace unsets
  * (bug fix)[3285375] Buffer overflow in [concat]
  * (internals change) revised TclFindElement() interface
  * ** POTENTIAL INCOMPATIBILITY ***
  * (enhancement) dict->list w/o string rep generation
  * (bug fix)[3173086] Crash parsing long lists
  * (bug fix)[2715421] surplus \n in POST => http 2.7.6
  * (enhancement) msgcat internal improvements => msgcat 1.4.4
  * (bug fix)[3185407] cmd resolution epoch flaw
  * (bug fix)[3315098] mem leak generating double string rep
  * (new cmd) [tcltest::loadIntoSlaveInterpreter]
    => tcltest 2.3.3
  * (new feature) DEB_HOST_MULTIARCH support => platform 1.0.10
- Add tcl-stack.patch to fix stack direction checking for gcc 4.6.
- Removed stack-3.1 from the list of known-failing tests.
- tcl-SafeLdExp.patch isn't needed anymore.
* Wed Apr 27 2011 idoenmez@novell.com
- Add stack-3.1 test to known failures, according to
  http://www.linuxfoundation.org/en/TestPilot32-U0710#Tcl_Tests___v_8.5a4-1_.3D
  it fails elsewhere too.
* Fri Sep  3 2010 max@suse.de
- Bugfix release 8.5.9:
  * [sf#2891556] encoding finalization crash
  * rewrite of the Safe Base commands
  * [sf#2913616] msgcat: improved safe interp support
    => msgcat 1.4.3
  * [sf#2913625] [info script/nameof] in safe interps
  * [sf#2891362] enable time limit in child interps
  * [sf#2895741] enable min(), max() in safe interps
  * [sf#2918610] [file rootname] corruption
  * [sf#2932421] less [format %%s] shimmer
  * [sf#2918110] [chan postevent] crash
  * [sf#2942697] faster match: some pathological regexp patterns
  * [sf#2939073] [array unset] unset trace crash
  * [sf#2933089] [info frame] shared lit trouble
  * [sf#2949740] [open |noSuch rb] crash
  * [sf#2954959] get sign of abs($zero) right
  * [sf#2936225] stop [chan copy] to slow channel consuming all
    memory with buffer backup
  * permit [fcopy] of > 2**31 bytes
  * [sf#2383005] [return -errorcode] reject non-list
  * [sf#2976504] broken fstatfs() call
  * [sf#2978773] refchan mem preservation
  * [sf#3004007] dict/list shimmer w/o string rep loss
  * platform: several fixes for 64 bit systems
    => platform 1.0.9
  * [sf#3016135] [clock format] in he_IL locale
  * (enhancement) -errorcode for [expr] domain errors
  * [sf#3037525] crash deleting vars @ callframe pop
  * [sf#3034840] mem corrupt when refchan loses interp
  * [sf#2826551] line-sensitive matching in regexp
  * [sf#3048354] buffer overflow detect in Fortify build
  * [sf#3057639] no read traces [lappend arr(elem) ...]
  * ** POTENTIAL INCOMPATIBILITY ***
* Mon May 17 2010 bg@novell.com
- Disable stack check for hppa to fix build.
* Fri Feb 19 2010 max@suse.de
- Add tcl-SafeLdExp.patch to prevent a floating point assist fault
  during startup on IA64 (bnc#578068).
* Thu Jan 21 2010 rguenther@suse.de
- Fix fortify violation in TraceVariableObjCmd.
* Wed Nov 18 2009 max@suse.de
- Bugfix release 8.5.8.
  * [info frame] account for continuation lines
  * account for ia64_32 => platform 1.0.5
  * improved error message in tcltest => tcltest 2.3.2
  * Broken DST applied EU rules to US zones
  * [sf#2446662] uniformly declare EOF on RST on sockets
  * [sf#1028264] delay WSACleanup() from under our feet
  * [sf#2785893] find command in deleted namespace
  * [sf#2798543] incorrect [expr] integer ** results
  * [sf#2801413] overflow in [format]
  * [sf#2802881] corrected compile env context
  * [sf#2819200] underflow settings on MIPS systems
  * [sf#2820349] plug event leak in notifier
  * [sf#2826248] crash in Tcl_GetChannelHandle
  * [sf#2830354] overflow in [format]
  * [sf#2827000] reflected channels can signal EGAIN
  * [sf#2806250] EIAS violation in ~foo pathnames
  * [sf#2837800] [glob */foo] return ./~x/foo
  * [sf#2845535] overflows in [format]
  * [sf#2849860] http handle "quoted" charset value
  * [sf#1941434] broken tclTomMath.h includes
  * [sf#2871908] leaked hash table
  * [sf#2874678] bignum leak in [dict incr]
  * [sf#2629338] crash in var unset traces
  * [sf#2107634] extend [read] and [gets] to Tcl string limits
  * [sf#2882561] Haiku OS signal support
  * [sf#2800740] halved bignum memory on 64-bit systems
    POTENTIAL INCOMPATIBILITY
  * [sf#2854929] TM search path support in Safe Base
  * [sf#2888099] [close] loses ENOSPC error
  * [sf#2891171] RFC 3986 compliance for ? in URL => http 2.7.5
  * [sf#2895565] [fcopy -size] miscounts when converting encodings
- Added tcl-unload.patch to fix a crash in the browser plugin.
* Sun Aug  2 2009 jansimon.moeller@opensuse.org
- disable the testsuite for the moment on ARM
* Tue Jun 16 2009 max@suse.de
- Install binaries unstripped to fix debuginfo packages.
* Wed Jun  3 2009 max@suse.de
- New release: 8.5.7:
  * Fix failure to read SHOUTcast streams in the http package.
  * Fix hang in channel finalization.
  * [file normalize] failed on some paths.
  * Fix crash with [chan create]d channel
  * Fix Tcl_FindCommand() bug exposed by oo.
  * Fix [string repeat] overflow crash.
  * Fix memleak in [file normalize].
  * Fix crash in Tcl_AppendStringToObj.
  * Fix Tcl_AppendObjToObj: append to self crash.
  * Fix several string overflows.
  * Fix [http::geturl] connection failures.
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Wed Oct 15 2008 max@suse.de
- Bugfix release 8.5.5:
  * Prevent overflow crash in [lrepeat].
  * Fixed crash in [namespace inscope] involving Tcl_ConcatObj().
  * Improved efficiency converting between lists and dicts.
  * Corrected failure to export [min] and [max] from
    ::tcl::mathfunc.
  * Fixed incorrect isqrt() results on a few values and platforms.
  * Tcl now only asks the system to unload shared libraries that
    explicitly Tcl's [unload] facility.
  * Corrected broken handling of ***= regular expressions.
* Mon Sep  8 2008 max@suse.de
- New release: 8.5.4:
  * fix mem leak in [seek] on reflected channels
  * preserve item intreps when converting from dict to list
  * [info frame] returns file data in more cases
  * fix rare panic in TclStackFree
  * 64bit support for http zlib crc
  * automatic [package provide] for TMs
* Thu Jul 10 2008 max@suse.de
- New release: 8.5.3:
  * Add support for bidirectional [fcopy].
  * Fix [fcopy] callbacks.
  * Fix [chan postevent] crash.
  * Fix broken [format {%% d}].
  * Fix [dict append] crash.
  * Fix crash in [glob -dir {} a].
  * Support TM packages in Safe Base.
* Wed May  7 2008 max@suse.de
- Added a fix and a test for a crash in the [dict append] command.
* Mon Apr  7 2008 max@suse.de
- Added /etc/rpm/macros.tcl
- Fixed behaviour of "%% d" format string.
* Wed Apr  2 2008 max@suse.de
- New release: 8.5.2:
  * Speed: 8.5 now runs 10%% faster than 8.4 with bytecode
    improvements, object caching and reduced memory usage.
  * Bignums: Tcl now supports arbitrary-precision integers, which
    improves math operations on large integers.
  * Safer interps: Tcl's powerful safe interpreter mechanism now
    has improved control of time and command limits in slave
    interpreters.
  * clock command: More robust implementation of command for
    specifying time, with significant l10n and i18n improvements.
  * dict command: New data structure that allows access to data
    by value rather than a variable name, which is substantially
    faster.
  * Additional improvements: Faster list search, new and improved
    mathematics procedures, anonymous procedures, new ways to
    package Tcl extensions, Tcl-level custom channel types, file
    and line location information for each command, and more.
  * More details in /usr/share/doc/packages/tcl/changes .
- Changed install locations for extensions: Compiled packages now
  go into their own subdir under /usr/lib{,64}/tcl, script-only
  packages go into /usr/share/tcl .
* Wed Jun  6 2007 max@suse.de
- New Patchlevel release: 8.4.15
- fix [file copy] on afs
- use > 32 async sockets on 64bit system
- fix list shimmer crash in [lsort]
- fix list shimmer crash in [foreach]
- fix list shimmer crash in [array set]
- fix buffer overflow in [registry keys]
* Tue Oct 17 2006 max@suse.de
- New patchlevel release: 8.4.14rc2
- srand() accept wide input.
- interactive Tcl_Main blocks main loop
- proc re-compile: preserve the previous bytecode while references
  still on the stack
- fixed [glob] on VFS
- fix intermittent failures in TclUnixWaitForFile()
- fix filesystem segfaults
- use of MT-safe system calls
- make [lappend $nonList] complain
- alignment fixes in unicode encoding routines
- [set ::http::strict 1] (default value is 0) to enable URL validity
  checking against RFC 2986
* Mon Sep 11 2006 max@suse.de
- New version: 8.4.13
- Fixes abs(MIN_INT) handling (obsoletes tcl-abs.patch)
- Fixes exec (#127822, obsoletes tcl-exec.patch)
- Several other bugfixes.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 max@suse.de
- Fixed a potential segfault in the exec command (#127822).
* Mon Dec 12 2005 max@suse.de
- Fixed abs(MIN_INT) handling.
* Thu Dec  8 2005 max@suse.de
- New version: 8.4.12
* Sun Nov  6 2005 schwab@suse.de
- Fix syntax error in unix configure script.
* Wed Jul 27 2005 max@suse.de
- New version: 8.4.11
- Fixed package loading path. Now Tcl extensions are found under
  /usr/share/tcl, /usr/lib, and on biarch platforms also under
  /usr/lib64.
* Tue Jun 14 2005 max@suse.de
- New version: 8.4.10
- Moved script libraries to /usr/share/tcl .
* Mon May  9 2005 max@suse.de
- Fixed profile-based optimisation with gcc4 (tcl-profile.patch).
* Mon Mar 21 2005 max@suse.de
- Added prerequisites for the trigger scripts (bug #74027).
* Fri Mar 18 2005 max@suse.de
- Make sure that tcl-32bit finds the script libraries when
  installed on a 64bit system.
* Fri Dec  3 2004 max@suse.de
- New version: 8.4.9
* Mon Nov 22 2004 max@suse.de
- New version: 8.4.8
* Thu Aug 19 2004 schwab@suse.de
- Fix broken tests that depend on particular directory order.
* Tue Jul 27 2004 max@suse.de
- New version: 8.4.7
* Thu May 27 2004 max@suse.de
- Added tcl-utf8-null.patch to fix bug #39165. Tcl wrote nullbytes
  as 0xc0, 0xc80 instead of 0x00 when writing to a UTF-8 encoded
  channel.
* Fri Mar  5 2004 max@suse.de
- Updated to the official 8.4.6 source tarball which fixes a
  memory leak.
* Fri Feb 27 2004 max@suse.de
- New version: 8.4.6
* Fri Feb  6 2004 max@suse.de
- Added -fno-strict-aliasing to CFLAGS.
* Tue Jan 20 2004 schwab@suse.de
- Move %%define before first use.
* Thu Jan 15 2004 max@suse.de
- Added LDFLAGS for gcc-3.4 and feedback based optimization.
* Mon Jan 12 2004 max@suse.de
- New version: 8.4.5
- Removed tclbench, since "make test" seems to be enough exercise
  for the feedback based optimization.
* Thu Oct  2 2003 max@suse.de
- Removed support for building static libs from the spec file.
- Added open-std-channels.patch to prevent tclsh from crashing
  when it's started with one or more of std{in,out,err} closed.
* Tue Sep  2 2003 max@suse.de
- Disabled building of the static library to save build time and
  CD space.
* Wed Aug 13 2003 max@suse.de
- Cleaned up the spec file from cruft, left from the times when it
  built multiple packages.
- Added support for GCC feedback based optimization.
- Added support for parallel compilaton.
* Thu Jul 24 2003 max@suse.de
- Fixed a typo, that broke [pkg_mkIndex -verbose].
* Wed Jul 23 2003 max@suse.de
- New version: 8.4.4
* Wed May 21 2003 max@suse.de
- New version: 8.4.3
- Removed obsolete patches
* Wed Mar  5 2003 max@suse.de
- Updated to official 8.4.2 release tarball
- Essental diff to RC1 added as tcl-20030305.path.gz
* Thu Feb 27 2003 max@suse.de
- Updated to 8.4.2 RC1, and added an essential diff to the
  previous tarball (tcl-20030227.patch.bz2).
- tcl-StringObj.patch is no longer needed.
- Disabled the httpold-4.12 test, because it sometimes fails on
  Hammer due to timing issues.
* Tue Feb 18 2003 max@suse.de
- Updated to CVS HEAD, and added diff to the previous tarball
  for completeness.
- Added tcl-StringObj.patch to fix a bug in conjunction
  with expect (Bug #23694).
- Made the testsuite break build if any test fails.
* Fri Feb  7 2003 max@suse.de
- Upgrade to CVS HEAD (8.4.2pre).
* Mon Nov 25 2002 max@suse.de
- Upgrade to 8.4.1
- Added tcl-HEAD.patch with fixes that went in after
  the 8.4.1 release.
- Moved itcl, iwidgets, tk, and tclx into separate soure packages.
* Mon Sep  9 2002 max@suse.de
- Added patch to final 8.4.0.
- Another couple of memleak and docu fixes.
* Thu Sep  5 2002 max@suse.de
- Next round of fixes (tcl8.4-20020905.patch tk8.4-20020905.patch).
- A detailed ChangeLog is at the top of the new patches.
- Removed autoconf and automake from neededforbuild.
* Tue Sep  3 2002 max@suse.de
- Another CVS snapshot for Tcl and Tk.
- The version numbers have been bumped from 8.4b3 to 8.4.0
- A couple more bug fixes. For details see the new ChangeLog
  entries in the patches.
* Mon Sep  2 2002 max@suse.de
- Added patches for to update Tcl and Tk to current CVS HEAD to
  fix some segfault cases and memleaks e.g. bug #18651.
  See ChangeLog for more details.
- Renamed Object.3 to Tcl_Obj.3 to resolve a name conflict.
* Thu Aug 15 2002 max@suse.de
- Updated Tcl and Tk to the latest CVS snapshot which is close
  to the official 8.4b2 release.
- Updated Itcl to 3.3 from CVS because it better fits with Tcl8.4.
- Removed excessive braces from RPM macros, and some more cleanups
  in the spec file.
- Using x-devel-packages instead of xf86 in needeforbuild.
- socklen_t.patch isn't needed anymore.
- Fixed CFLAGS (-fPIC) for TclX.
- Updated TclX to 8.4 from CVS (needed for Tcl/Tk 8.4).
  This doesn't include /usr/bin/tcl and /usr/bin/wishx anymore.
  In case a script needs one of them, please use a normal tclsh
  or wish and add a line saying "package require Tclx" to the
  beginning of the script.
* Fri Jul 26 2002 max@suse.de
- Removed gdb from #neededforbuild.
* Mon Jul 22 2002 max@suse.de
- Updated to the latest CVS HEAD.
- Fixed socket calls on s390x (socklen_t.patch).
* Mon Jul  1 2002 max@suse.de
- New Versions of Tcl and Tk: 8.4b1
* Fri Jun  7 2002 max@suse.de
- New Version of tkcon: 2.3.
- Fixed directory permissions in iwidgets.
- Put things that are common to all subpackages into shell
  functions to make maintainance of the spec file easier.
* Wed Apr 24 2002 max@suse.de
- Fixed creation of Tk's pkgIndex.tcl.
- Fixed permissions and path to wish in iwidgets demo scripts.
* Wed Apr  3 2002 ro@suse.de
- fix to build with latest autoconf (LIBOBJS vs. AC_LIBOBJ)
* Wed Feb 20 2002 uli@suse.de
- fixed to build on ARM
* Wed Feb 20 2002 max@suse.de
- Fixed for lib64-s390x (libdir.patch).
- Running the testsuite after building Tcl.
* Mon Feb 18 2002 max@suse.de
- Changed TclX to use -fPIC instead of -fpic .
* Wed Feb  6 2002 max@suse.de
- Fixed a typo in the http package.
- Moved iwidgets out of the itcl dir.
* Thu Jan 17 2002 max@suse.de
- Moved Tix and Expect back into their own source packages.
- Added some private headers to tcl-devel to be able to
  build Tix and Expect independent of the Tcl/Tk sources.
- replaced %%{_prefix}/lib by %%{_libdir} where apropriate
* Fri Dec 14 2001 uli@suse.de
- build static only on ARM
* Fri Nov 16 2001 schwab@suse.de
- Use $(SHLIB_CFLAGS) in itcl makefiles.
* Mon Oct 29 2001 max@suse.de
- New versions:
  o Tcl/Tk 8.3.4
  o expect 5.33.0
  o Tix 8.1.1
  o [incr Tcl/Tk] 3.2.1
  o [incr Widgets] 4.0.0
- Included tkcon-2.2 with Tk.
- Removed unnecessary explicit dependencies between
  the subpackages.
- Changed the memory man page back to the one that comes with Tcl.
- Changed the -C configure switch to be only used when needed and
  supported.
* Fri Sep 21 2001 max@suse.de
- replaced the "memory" man page from Tcl with the one from TclX,
  because it is better and there was a filename clash in the two
  packages before.
* Mon Jun 18 2001 schwab@suse.de
- Fix TK_XINCLUDES in tkConfig.sh.
* Wed Jun 13 2001 schwab@suse.de
- Add %%suse_update_config.
- Fix for new autoconf (force use of cache file).
* Tue May  8 2001 mfabian@suse.de
- bzip2 sources
* Tue Apr 10 2001 max@suse.de
- new version of Tcl/Tk: 8.3.3
* Mon Apr  2 2001 max@suse.de
- security fix for expect (/var/tmp/[...] was in rpath).
* Thu Mar  8 2001 max@suse.de
- made exclusion of static libs for manual builds more robust
* Wed Mar  7 2001 max@suse.de
- added xdevel and xshared to #neededforbuild
- using %%if to exclude things when building without static libs.
* Wed Jan 10 2001 max@suse.de
- Fixed a bug itcl's manpage installation -
  man.macros was not copied into the individual manpages.
* Mon Jan  8 2001 max@suse.de
- Enabling XIM by default.
  This fixes the compose and deadkey problem. Bug #5234
* Tue Dec 19 2000 max@suse.de
- Fix for race condition with tmpnam(3) in tclUnixPipe.c
* Thu Nov 30 2000 ro@suse.de
- try to fix static-lib install
* Thu Nov 30 2000 max@suse.de
- re-enabled static libs
* Wed Nov 29 2000 max@suse.de
- renamed tcld to tcl-devel
- new version of Tcl/Tk: 8.3.2
- new version of [incr Tcl]: 3.2
- new version of TclX: 8.3.2
- new version of expect: 5.32
- new version of Tix: 8.1.0
* Fri Nov 24 2000 schwab@suse.de
- Fix typo in itk makefile.
* Tue Nov 14 2000 ro@suse.de
- use "export LANG=en_US" to make it build despite col bug
* Wed Sep 13 2000 max@suse.de
- When running in build or autobuild, configure didn't recognize
  the termios API, because the check needed stdin to be a tty.
  Changed tcl.m4 to fix this by relying on the existance of
  termios.h .
* Wed May 31 2000 max@suse.de
- New version of Tix: 4.1.007
- Applied Bruce Stephens' Patch to make Tix work with Tcl/Tk 8.3
  http://www.egroups.com/message/tix/494
* Wed May 17 2000 schwab@suse.de
- Recover bug fixes.
* Thu May  4 2000 max@suse.de
- new version of Tcl/Tk: 8.3.1
- new version of TclX: 8.2.0
- new version of expect: 5.31
- new version of itcl: 3.1.0
- the package uses RPM_BUILD_ROOT now
- some of schwab's bad documented "fixes" got lost
* Fri Apr 14 2000 schwab@suse.de
- Use $RPM_OPT_FLAGS as default CFLAGS.
- expect, tix: fix missing declarations.
- itcl: make sure we link to the libraries just built.
* Wed Apr 12 2000 schwab@suse.de
- expect: make sure ptsname is declared.
- tclX: fix autoconf check for clock_t (look in <time.t>)
* Mon Feb 28 2000 schwab@suse.de
- Add group tags
- expect: use --localdir with autoreconf, update config.{guess,sub}
- tcl: fix printf formats
* Thu Feb 24 2000 schwab@suse.de
- Fix 64 Bit Bug in expect.
* Tue Jan 25 2000 kukuk@suse.de
- Remove autopasswd, mkpasswd and tkpasswd from expect file list.
  They will not work with PAM. Fixes [Bug 638] and [Bug 1554]
* Sat Nov 27 1999 kukuk@suse.de
- Fix duplicate SIGPWR/SIGLOST on SPARC
* Mon Nov 15 1999 kasal@suse.de
- fixed a few minor bugs in spec file, mainly:
  call "autoreconf --force" instead of "autoconf" to regenerate
  also the configure scripts in subdirs
  rm *.o before creating the dynamic version of the library
* Mon Nov  8 1999 max@suse.de
- added some compatibility links:
  /usr/X11R6/bin/wish -> ../../bin/wish8.0
  /usr/X11R6/bin/wish8.0 -> ../../bin/wish8.0
  /usr/X11R6/bin/tixwish -> ../../bin/tixwish4.1.8.0
  /usr/X11R6/bin/tixwish4.1.8.0 -> ../../bin/tixwish4.1.8.0
* Fri Oct  8 1999 max@suse.de
- integrated tclX8.0.4 as an additional subpackage
* Thu Oct  7 1999 max@suse.de
- integrated expect-5.30 as an additional subpackage
- changed the names of some tk manpages because they
  interferred with itcl
- removed the tix-sam libraries from tcld
* Thu Sep 30 1999 max@suse.de
- this is a test version for the beta distribution
- major rework of the spec-file
- renamed the packages from tcl_new, tk_new, etc. to tcl, tk, etc.
- Moved Tk from /usr/X11R6 to /usr.
- Moved Tix from /usr/lib/tcltk to /usr/lib
- Included itcl 3.0.1 as a subpackage
- There is a new subpackage, called tcld that holds all the
  static libs and header files for Tcl, Tk, Tix and Itcl.
- Most file lists are auto-generated now.
* Mon Sep 27 1999 bs@suse.de
- fixed requirements for sub packages
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Sun Mar 14 1999 max@suse.de
- new version: 8.0.5
- ro's patch from Mon Sep 21 1998 is not needed anymore
* Tue Mar  2 1999 ro@suse.de
- changed macro TK to TKK in specfile
  2char macros don't seem to work in current rpm
* Thu Jan 14 1999 max@suse.de
- fixed path bug with applications linked against libtk which do
  not reside in /usr/X11R6
* Wed Nov 25 1998 max@suse.de
- corrected some paths in tix to make it find its init script
  and libraries correctly
* Tue Nov 24 1998 max@suse.de
- merged spec files of tcl_new, tk_new and tix_new into tcl_new.spec
- this changes file is from now on for all three packages
* Mon Nov 23 1998 max@suse.de
- new version: 8.0.4
- cleand up softlinks and compression for man pages
* Mon Sep 21 1998 ro@suse.de
- for GLIBC EOPNOTSUPP and ENOTSUP seem to map to same value
- catch duplicate cases for this reason in tclPosixStr.c
* Mon Nov 10 1997 hf@suse.de
  new version 8.0p1
* Mon Oct 27 1997 hf@suse.de
  ready for autobuild
* Thu Jul  3 1997 hf@suse.de
  A new release 8.0b2, the second (and probably final) beta release for
  Tcl 8.0.
* Tue Jun  3 1997 hf@suse.de
- added static librs and all links for the manpages in
    the /usr/doc/packages/tcl8.0/man
* Tue Apr 15 1997 hf@suse.de
- manpages    hardlinks removed and added softlinks to
    compressd manpages
    the new directory for the manpages is
  /usr/doc/packeges/tcl8.0/man
